@@ -27,7 +27,7 @@ class MiniECS:
         self.sock = socket.create_connection((self.address, self.port))
         self.containers_list = []
 
-    def stop():
+    def stop(self):
         self.sock.close()
 
     def create_container(self, name: str):
